aboutsummaryrefslogtreecommitdiffstats
path: root/src/java/org
diff options
context:
space:
mode:
authorGlen Mazza <gmazza@apache.org>2004-09-06 18:44:33 +0000
committerGlen Mazza <gmazza@apache.org>2004-09-06 18:44:33 +0000
commita27c6a935b4417af213a392c68df80434e17490f (patch)
tree85d99a78cdccb20b1083359e1fb4b4c61875be45 /src/java/org
parent42dc46911b6f085878be224ab0787e69a524fcb0 (diff)
downloadxmlgraphics-fop-a27c6a935b4417af213a392c68df80434e17490f.tar.gz
xmlgraphics-fop-a27c6a935b4417af213a392c68df80434e17490f.zip
Renamed FOInputHandler to somewhat more intuitive FOEventHandler.
git-svn-id: https://svn.apache.org/repos/asf/xmlgraphics/fop/trunk@197911 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'src/java/org')
-rw-r--r--src/java/org/apache/fop/area/AreaTreeHandler.java4
-rw-r--r--src/java/org/apache/fop/fo/FOEventHandler.java (renamed from src/java/org/apache/fop/fo/FOInputHandler.java)12
-rw-r--r--src/java/org/apache/fop/fo/FONode.java22
-rw-r--r--src/java/org/apache/fop/fo/FOTreeBuilder.java16
-rw-r--r--src/java/org/apache/fop/fo/FObj.java2
-rw-r--r--src/java/org/apache/fop/fo/FObjMixed.java6
-rw-r--r--src/java/org/apache/fop/fo/flow/BasicLink.java4
-rw-r--r--src/java/org/apache/fop/fo/flow/Block.java4
-rw-r--r--src/java/org/apache/fop/fo/flow/ExternalGraphic.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/Float.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/Footnote.java6
-rw-r--r--src/java/org/apache/fop/fo/flow/FootnoteBody.java6
-rw-r--r--src/java/org/apache/fop/fo/flow/Inline.java4
-rw-r--r--src/java/org/apache/fop/fo/flow/InstreamForeignObject.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/Leader.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/ListBlock.java6
-rw-r--r--src/java/org/apache/fop/fo/flow/ListItem.java6
-rw-r--r--src/java/org/apache/fop/fo/flow/ListItemLabel.java4
-rw-r--r--src/java/org/apache/fop/fo/flow/MultiProperties.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/MultiSwitch.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/PageNumber.java6
-rw-r--r--src/java/org/apache/fop/fo/flow/Table.java4
-rw-r--r--src/java/org/apache/fop/fo/flow/TableAndCaption.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/TableBody.java4
-rw-r--r--src/java/org/apache/fop/fo/flow/TableCaption.java2
-rw-r--r--src/java/org/apache/fop/fo/flow/TableCell.java6
-rw-r--r--src/java/org/apache/fop/fo/flow/TableColumn.java4
-rw-r--r--src/java/org/apache/fop/fo/flow/TableRow.java4
-rw-r--r--src/java/org/apache/fop/fo/pagination/Flow.java6
-rw-r--r--src/java/org/apache/fop/fo/pagination/PageSequence.java4
-rw-r--r--src/java/org/apache/fop/fo/pagination/Root.java2
-rw-r--r--src/java/org/apache/fop/fo/pagination/StaticContent.java4
-rw-r--r--src/java/org/apache/fop/layoutmgr/BlockLayoutManager.java2
-rw-r--r--src/java/org/apache/fop/layoutmgr/CharacterLayoutManager.java2
-rw-r--r--src/java/org/apache/fop/layoutmgr/PageNumberCitationLayoutManager.java2
-rw-r--r--src/java/org/apache/fop/render/mif/MIFHandler.java90
-rw-r--r--src/java/org/apache/fop/render/rtf/RTFHandler.java106
37 files changed, 182 insertions, 182 deletions
diff --git a/src/java/org/apache/fop/area/AreaTreeHandler.java b/src/java/org/apache/fop/area/AreaTreeHandler.java
index e33423fb0..ad1822e98 100644
--- a/src/java/org/apache/fop/area/AreaTreeHandler.java
+++ b/src/java/org/apache/fop/area/AreaTreeHandler.java
@@ -34,7 +34,7 @@ import org.xml.sax.SAXException;
import org.apache.fop.apps.FOPException;
import org.apache.fop.apps.FOUserAgent;
import org.apache.fop.area.extensions.BookmarkData;
-import org.apache.fop.fo.FOInputHandler;
+import org.apache.fop.fo.FOEventHandler;
import org.apache.fop.fo.FObj;
import org.apache.fop.fo.extensions.Outline;
import org.apache.fop.fo.extensions.Bookmarks;
@@ -69,7 +69,7 @@ import java.util.Iterator;
* The area tree pages are organized in a model that depends on the
* type of renderer.
*/
-public class AreaTreeHandler extends FOInputHandler {
+public class AreaTreeHandler extends FOEventHandler {
// TODO: Collecting of statistics should be configurable
private final boolean collectStatistics = true;
diff --git a/src/java/org/apache/fop/fo/FOTreeBuilder.java b/src/java/org/apache/fop/fo/FOTreeBuilder.java
index a5b94d978..4d0787bc3 100644
--- a/src/java/org/apache/fop/fo/FOTreeBuilder.java
+++ b/src/java/org/apache/fop/fo/FOTreeBuilder.java
@@ -84,7 +84,7 @@ public class FOTreeBuilder extends DefaultHandler {
* The class that handles formatting and rendering to a stream
* (mark-fop@inomial.com)
*/
- private FOInputHandler foInputHandler;
+ private FOEventHandler foEventHandler;
/** The SAX locator object managing the line and column counters */
private Locator locator;
@@ -107,9 +107,9 @@ public class FOTreeBuilder extends DefaultHandler {
}
if (renderType == Constants.RENDER_MIF) {
- foInputHandler = new MIFHandler(foUserAgent, stream);
+ foEventHandler = new MIFHandler(foUserAgent, stream);
} else if (renderType == Constants.RENDER_RTF) {
- foInputHandler = new RTFHandler(foUserAgent, stream);
+ foEventHandler = new RTFHandler(foUserAgent, stream);
} else {
if (renderType < Constants.RENDER_MIN_CONST
|| renderType > Constants.RENDER_MAX_CONST) {
@@ -117,7 +117,7 @@ public class FOTreeBuilder extends DefaultHandler {
"Invalid render ID#" + renderType);
}
- foInputHandler = new AreaTreeHandler(foUserAgent, renderType,
+ foEventHandler = new AreaTreeHandler(foUserAgent, renderType,
stream);
}
@@ -217,11 +217,11 @@ public class FOTreeBuilder extends DefaultHandler {
*/
public void startDocument() throws SAXException {
rootFObj = null; // allows FOTreeBuilder to be reused
- FONode.setFOInputHandler(foInputHandler);
+ FONode.setFOEventHandler(foEventHandler);
if (log.isDebugEnabled()) {
log.debug("Building formatting object tree");
}
- foInputHandler.startDocument();
+ foEventHandler.startDocument();
}
/**
@@ -234,7 +234,7 @@ public class FOTreeBuilder extends DefaultHandler {
if (log.isDebugEnabled()) {
log.debug("Parsing of document complete");
}
- foInputHandler.endDocument();
+ foEventHandler.endDocument();
}
/**
@@ -355,7 +355,7 @@ public class FOTreeBuilder extends DefaultHandler {
public void reset() {
currentFObj = null;
rootFObj = null;
- foInputHandler = null;
+ foEventHandler = null;
}
}
diff --git a/src/java/org/apache/fop/fo/FObj.java b/src/java/org/apache/fop/fo/FObj.java
index bcaf8906b..afe60619e 100644
--- a/src/java/org/apache/fop/fo/FObj.java
+++ b/src/java/org/apache/fop/fo/FObj.java
@@ -140,7 +140,7 @@ public class FObj extends FONode implements Constants {
if (prop != null) {
String str = prop.getString();
if (str != null && !str.equals("")) {
- Set idrefs = getFOInputHandler().getIDReferences();
+ Set idrefs = getFOEventHandler().getIDReferences();
if (!idrefs.contains(str)) {
id = str;
idrefs.add(id);
diff --git a/src/java/org/apache/fop/fo/FObjMixed.java b/src/java/org/apache/fop/fo/FObjMixed.java
index 8e82b3e0c..cbaa34b99 100644
--- a/src/java/org/apache/fop/fo/FObjMixed.java
+++ b/src/java/org/apache/fop/fo/FObjMixed.java
@@ -51,14 +51,14 @@ public class FObjMixed extends FObj {
if (textInfo == null) {
// Really only need one of these, but need to get fontInfo
// stored in propMgr for later use.
- propMgr.setFontInfo(getFOInputHandler().getFontInfo());
- textInfo = propMgr.getTextLayoutProps(getFOInputHandler().getFontInfo());
+ propMgr.setFontInfo(getFOEventHandler().getFontInfo());
+ textInfo = propMgr.getTextLayoutProps(getFOEventHandler().getFontInfo());
}
FOText ft = new FOText(data, start, length, textInfo, this);
ft.setLocator(locator);
- getFOInputHandler().characters(ft.ca, ft.startIndex, ft.endIndex);
+ getFOEventHandler().characters(ft.ca, ft.startIndex, ft.endIndex);
addChildNode(ft);
}
diff --git a/src/java/org/apache/fop/fo/flow/BasicLink.java b/src/java/org/apache/fop/fo/flow/BasicLink.java
index d8cd6775a..04a244037 100644
--- a/src/java/org/apache/fop/fo/flow/BasicLink.java
+++ b/src/java/org/apache/fop/fo/flow/BasicLink.java
@@ -77,7 +77,7 @@ public class BasicLink extends Inline {
"internal-destination must be specified.");
}
- getFOInputHandler().startLink(this);
+ getFOEventHandler().startLink(this);
}
/**
@@ -102,7 +102,7 @@ public class BasicLink extends Inline {
*/
protected void endOfNode() throws SAXParseException {
super.endOfNode();
- getFOInputHandler().endLink();
+ getFOEventHandler().endLink();
}
/**
diff --git a/src/java/org/apache/fop/fo/flow/Block.java b/src/java/org/apache/fop/fo/flow/Block.java
index bcecb48fa..c7405b546 100644
--- a/src/java/org/apache/fop/fo/flow/Block.java
+++ b/src/java/org/apache/fop/fo/flow/Block.java
@@ -122,7 +122,7 @@ public class Block extends FObjMixed {
this.blockOrphans =
this.propertyList.get(PR_ORPHANS).getNumber().intValue();
- getFOInputHandler().startBlock(this);
+ getFOEventHandler().startBlock(this);
}
/**
@@ -188,7 +188,7 @@ public class Block extends FObjMixed {
*/
protected void endOfNode() throws SAXParseException {
handleWhiteSpace();
- getFOInputHandler().endBlock(this);
+ getFOEventHandler().endBlock(this);
}
private void handleWhiteSpace() {
diff --git a/src/java/org/apache/fop/fo/flow/ExternalGraphic.java b/src/java/org/apache/fop/fo/flow/ExternalGraphic.java
index fac67bf5a..0bb8bd5cb 100644
--- a/src/java/org/apache/fop/fo/flow/ExternalGraphic.java
+++ b/src/java/org/apache/fop/fo/flow/ExternalGraphic.java
@@ -62,7 +62,7 @@ public class ExternalGraphic extends FObj {
*/
protected void addProperties(Attributes attlist) throws SAXParseException {
super.addProperties(attlist);
- getFOInputHandler().image(this);
+ getFOEventHandler().image(this);
}
/**
diff --git a/src/java/org/apache/fop/fo/flow/Float.java b/src/java/org/apache/fop/fo/flow/Float.java
index 3a9c61806..8e3bad5e4 100644
--- a/src/java/org/apache/fop/fo/flow/Float.java
+++ b/src/java/org/apache/fop/fo/flow/Float.java
@@ -59,7 +59,7 @@ public class Float extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
diff --git a/src/java/org/apache/fop/fo/flow/Inline.java b/src/java/org/apache/fop/fo/flow/Inline.java
index 33605498f..490c98ef9 100644
--- a/src/java/org/apache/fop/fo/flow/Inline.java
+++ b/src/java/org/apache/fop/fo/flow/Inline.java
@@ -69,7 +69,7 @@ public class Inline extends FObjMixed {
}
}
- getFOInputHandler().startInline(this);
+ getFOEventHandler().startInline(this);
}
/**
@@ -105,7 +105,7 @@ public class Inline extends FObjMixed {
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
- getFOInputHandler().endInline(this);
+ getFOEventHandler().endInline(this);
}
/**
diff --git a/src/java/org/apache/fop/fo/flow/InstreamForeignObject.java b/src/java/org/apache/fop/fo/flow/InstreamForeignObject.java
index ba87618e1..40475ac8e 100644
--- a/src/java/org/apache/fop/fo/flow/InstreamForeignObject.java
+++ b/src/java/org/apache/fop/fo/flow/InstreamForeignObject.java
@@ -66,7 +66,7 @@ public class InstreamForeignObject extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
diff --git a/src/java/org/apache/fop/fo/flow/Leader.java b/src/java/org/apache/fop/fo/flow/Leader.java
index 6582c3672..91fafb0b3 100644
--- a/src/java/org/apache/fop/fo/flow/Leader.java
+++ b/src/java/org/apache/fop/fo/flow/Leader.java
@@ -57,7 +57,7 @@ public class Leader extends FObjMixed {
*/
private void setup() {
// Common Font Properties
- this.fontState = propMgr.getFontState(getFOInputHandler().getFontInfo());
+ this.fontState = propMgr.getFontState(getFOEventHandler().getFontInfo());
// color properties
ColorType c = this.propertyList.get(PR_COLOR).getColorType();
diff --git a/src/java/org/apache/fop/fo/flow/ListItemLabel.java b/src/java/org/apache/fop/fo/flow/ListItemLabel.java
index b117bcb87..9f57ac212 100644
--- a/src/java/org/apache/fop/fo/flow/ListItemLabel.java
+++ b/src/java/org/apache/fop/fo/flow/ListItemLabel.java
@@ -44,7 +44,7 @@ public class ListItemLabel extends FObj {
*/
protected void addProperties(Attributes attlist) throws SAXParseException {
super.addProperties(attlist);
- getFOInputHandler().startListLabel();
+ getFOEventHandler().startListLabel();
/*
* For calculating the lineage - The fo:list-item-label formatting object
* does not generate any areas. The fo:list-item-label formatting object
@@ -55,7 +55,7 @@ public class ListItemLabel extends FObj {
protected void endOfNode() throws SAXParseException {
super.endOfNode();
- getFOInputHandler().endListLabel();
+ getFOEventHandler().endListLabel();
}
public String getName() {
diff --git a/src/java/org/apache/fop/fo/flow/MultiProperties.java b/src/java/org/apache/fop/fo/flow/MultiProperties.java
index 7463d4aa8..3a1e5ac4c 100644
--- a/src/java/org/apache/fop/fo/flow/MultiProperties.java
+++ b/src/java/org/apache/fop/fo/flow/MultiProperties.java
@@ -75,7 +75,7 @@ public class MultiProperties extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
diff --git a/src/java/org/apache/fop/fo/flow/MultiSwitch.java b/src/java/org/apache/fop/fo/flow/MultiSwitch.java
index bc075ab7f..fffd00e8b 100644
--- a/src/java/org/apache/fop/fo/flow/MultiSwitch.java
+++ b/src/java/org/apache/fop/fo/flow/MultiSwitch.java
@@ -60,7 +60,7 @@ public class MultiSwitch extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
diff --git a/src/java/org/apache/fop/fo/flow/PageNumber.java b/src/java/org/apache/fop/fo/flow/PageNumber.java
index 13d1d43c0..e670e121d 100644
--- a/src/java/org/apache/fop/fo/flow/PageNumber.java
+++ b/src/java/org/apache/fop/fo/flow/PageNumber.java
@@ -68,7 +68,7 @@ public class PageNumber extends FObj {
super.addProperties(attlist);
// Common Font Properties
- this.fontState = propMgr.getFontState(getFOInputHandler().getFontInfo());
+ this.fontState = propMgr.getFontState(getFOEventHandler().getFontInfo());
ColorType c = this.propertyList.get(PR_COLOR).getColorType();
this.red = c.getRed();
@@ -76,7 +76,7 @@ public class PageNumber extends FObj {
this.blue = c.getBlue();
this.wrapOption = getPropEnum(PR_WRAP_OPTION);
- getFOInputHandler().startPageNumber(this);
+ getFOEventHandler().startPageNumber(this);
}
/**
@@ -87,7 +87,7 @@ public class PageNumber extends FObj {
}
protected void endOfNode() throws SAXParseException {
- getFOInputHandler().endPageNumber(this);
+ getFOEventHandler().endPageNumber(this);
}
/**
diff --git a/src/java/org/apache/fop/fo/flow/Table.java b/src/java/org/apache/fop/fo/flow/Table.java
index 8373727bb..f3cc5249d 100644
--- a/src/java/org/apache/fop/fo/flow/Table.java
+++ b/src/java/org/apache/fop/fo/flow/Table.java
@@ -99,11 +99,11 @@ public class Table extends FObj {
== TableOmitHeaderAtBreak.TRUE;
this.omitFooterAtBreak = getPropEnum(PR_TABLE_OMIT_FOOTER_AT_BREAK)
== TableOmitFooterAtBreak.TRUE;
- getFOInputHandler().startTable(this);
+ getFOEventHandler().startTable(this);
}
protected void endOfNode() throws SAXParseException {
- getFOInputHandler().endTable(this);
+ getFOEventHandler().endTable(this);
}
/**
diff --git a/src/java/org/apache/fop/fo/flow/TableAndCaption.java b/src/java/org/apache/fop/fo/flow/TableAndCaption.java
index 0229b0cb3..7b52fd9e3 100644
--- a/src/java/org/apache/fop/fo/flow/TableAndCaption.java
+++ b/src/java/org/apache/fop/fo/flow/TableAndCaption.java
@@ -85,7 +85,7 @@ public class TableAndCaption extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
diff --git a/src/java/org/apache/fop/fo/flow/TableBody.java b/src/java/org/apache/fop/fo/flow/TableBody.java
index 342684c50..8ced5f71b 100644
--- a/src/java/org/apache/fop/fo/flow/TableBody.java
+++ b/src/java/org/apache/fop/fo/flow/TableBody.java
@@ -58,11 +58,11 @@ public class TableBody extends FObj {
this.spaceAfter = getPropLength(PR_SPACE_AFTER | CP_OPTIMUM);
this.backgroundColor =
this.propertyList.get(PR_BACKGROUND_COLOR).getColorType();
- getFOInputHandler().startBody(this);
+ getFOEventHandler().startBody(this);
}
protected void endOfNode() throws SAXParseException {
- getFOInputHandler().endBody(this);
+ getFOEventHandler().endBody(this);
}
/**
diff --git a/src/java/org/apache/fop/fo/flow/TableCaption.java b/src/java/org/apache/fop/fo/flow/TableCaption.java
index b76577156..10e8f7f44 100644
--- a/src/java/org/apache/fop/fo/flow/TableCaption.java
+++ b/src/java/org/apache/fop/fo/flow/TableCaption.java
@@ -69,7 +69,7 @@ public class TableCaption extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
diff --git a/src/java/org/apache/fop/fo/flow/TableColumn.java b/src/java/org/apache/fop/fo/flow/TableColumn.java
index 0ab7a4215..a6e30f2dc 100644
--- a/src/java/org/apache/fop/fo/flow/TableColumn.java
+++ b/src/java/org/apache/fop/fo/flow/TableColumn.java
@@ -69,14 +69,14 @@ public class TableColumn extends FObj {
this.propertyList.get(PR_BACKGROUND_COLOR).getColorType();
columnWidth = this.propertyList.get(PR_COLUMN_WIDTH).getLength();
- getFOInputHandler().startColumn(this);
+ getFOEventHandler().startColumn(this);
}
/**
* @see org.apache.fop.fo.FONode#endOfNode
*/
protected void endOfNode() throws SAXParseException {
- getFOInputHandler().endColumn(this);
+ getFOEventHandler().endColumn(this);
}
/**
diff --git a/src/java/org/apache/fop/fo/flow/TableRow.java b/src/java/org/apache/fop/fo/flow/TableRow.java
index 3e6f1700f..680cb0b65 100644
--- a/src/java/org/apache/fop/fo/flow/TableRow.java
+++ b/src/java/org/apache/fop/fo/flow/TableRow.java
@@ -64,12 +64,12 @@ public class TableRow extends FObj {
*/
protected void addProperties(Attributes attlist) throws SAXParseException {
super.addProperties(attlist);
- getFOInputHandler().startRow(this);
+ getFOEventHandler().startRow(this);
}
protected void endOfNode() throws SAXParseException {
- getFOInputHandler().endRow(this);
+ getFOEventHandler().endRow(this);
}
/**
diff --git a/src/java/org/apache/fop/fo/pagination/PageSequence.java b/src/java/org/apache/fop/fo/pagination/PageSequence.java
index 9e9f54f47..c2dd48ebc 100644
--- a/src/java/org/apache/fop/fo/pagination/PageSequence.java
+++ b/src/java/org/apache/fop/fo/pagination/PageSequence.java
@@ -245,7 +245,7 @@ public class PageSequence extends FObj {
missingChildElementError("(title?,static-content*,flow)");
}
- getFOInputHandler().endPageSequence(this);
+ getFOEventHandler().endPageSequence(this);
}
/**
@@ -278,7 +278,7 @@ public class PageSequence extends FObj {
*/
private void startStructuredPageSequence() {
if (!sequenceStarted) {
- getFOInputHandler().startPageSequence(this);
+ getFOEventHandler().startPageSequence(this);
sequenceStarted = true;
}
}
diff --git a/src/java/org/apache/fop/fo/pagination/Root.java b/src/java/org/apache/fop/fo/pagination/Root.java
index 71e0c5ffe..35ec7c0ca 100644
--- a/src/java/org/apache/fop/fo/pagination/Root.java
+++ b/src/java/org/apache/fop/fo/pagination/Root.java
@@ -30,7 +30,7 @@ import org.apache.fop.fo.FONode;
import org.apache.fop.fo.FObj;
import org.apache.fop.fo.extensions.ExtensionElementMapping;
import org.apache.fop.fo.extensions.Bookmarks;
-import org.apache.fop.fo.FOInputHandler;
+import org.apache.fop.fo.FOEventHandler;
/**
* The fo:root formatting object. Contains page masters, page-sequences.
diff --git a/src/java/org/apache/fop/layoutmgr/BlockLayoutManager.java b/src/java/org/apache/fop/layoutmgr/BlockLayoutManager.java
index 8840fccca..5a997bb97 100644
--- a/src/java/org/apache/fop/layoutmgr/BlockLayoutManager.java
+++ b/src/java/org/apache/fop/layoutmgr/BlockLayoutManager.java
@@ -76,7 +76,7 @@ public class BlockLayoutManager extends BlockStackingLayoutManager {
proxyLMiter = new ProxyLMiter();
userAgent = inBlock.getUserAgent();
setBlockTextInfo(inBlock.getPropertyManager().getTextLayoutProps(
- inBlock.getFOInputHandler().getFontInfo()));
+ inBlock.getFOEventHandler().getFontInfo()));
}
private void setBlockTextInfo(TextInfo ti) {
diff --git a/src/java/org/apache/fop/layoutmgr/CharacterLayoutManager.java b/src/java/org/apache/fop/layoutmgr/CharacterLayoutManager.java
index d028cd684..ef42b675a 100644
--- a/src/java/org/apache/fop/layoutmgr/CharacterLayoutManager.java
+++ b/src/java/org/apache/fop/layoutmgr/CharacterLayoutManager.java
@@ -49,7 +49,7 @@ public class CharacterLayoutManager extends LeafNodeLayoutManager {
setCurrentArea(inline);
textInfo = node.getPropertyManager().getTextLayoutProps
- (node.getFOInputHandler().getFontInfo());
+ (node.getFOEventHandler().getFontInfo());
SpaceVal ls = textInfo.letterSpacing;
letterSpaceIPD = new MinOptMax(ls.getSpace().min,
ls.getSpace().opt,
diff --git a/src/java/org/apache/fop/layoutmgr/PageNumberCitationLayoutManager.java b/src/java/org/apache/fop/layoutmgr/PageNumberCitationLayoutManager.java
index acd674b94..7ea98e390 100644
--- a/src/java/org/apache/fop/layoutmgr/PageNumberCitationLayoutManager.java
+++ b/src/java/org/apache/fop/layoutmgr/PageNumberCitationLayoutManager.java
@@ -46,7 +46,7 @@ public class PageNumberCitationLayoutManager extends LeafNodeLayoutManager {
*/
public PageNumberCitationLayoutManager(PageNumberCitation node) {
super(node);
- font = node.getPropertyManager().getFontState(node.getFOInputHandler().getFontInfo());
+ font = node.getPropertyManager().getFontState(node.getFOEventHandler().getFontInfo());
pncNode = node;
}
diff --git a/src/java/org/apache/fop/render/mif/MIFHandler.java b/src/java/org/apache/fop/render/mif/MIFHandler.java
index 2a50c3536..d74ed4bcc 100644
--- a/src/java/org/apache/fop/render/mif/MIFHandler.java
+++ b/src/java/org/apache/fop/render/mif/MIFHandler.java
@@ -25,7 +25,7 @@ import java.io.OutputStream;
import org.apache.fop.apps.FOUserAgent;
import org.apache.fop.apps.FOPException;
import org.apache.fop.fo.Constants;
-import org.apache.fop.fo.FOInputHandler;
+import org.apache.fop.fo.FOEventHandler;
import org.apache.fop.fo.flow.BasicLink;
import org.apache.fop.fo.flow.Block;
import org.apache.fop.fo.flow.ExternalGraphic;
@@ -57,7 +57,7 @@ import org.xml.sax.SAXException;
* the FO Tree sent to this structure handler.
* This builds an MIF file and writes it to the output.
*/
-public class MIFHandler extends FOInputHandler {
+public class MIFHandler extends FOEventHandler {
/** the MIFFile instance */
protected MIFFile mifFile;
@@ -81,7 +81,7 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startDocument()
+ * @see org.apache.fop.fo.FOEventHandler#startDocument()
*/
public void startDocument() throws SAXException {
mifFile = new MIFFile();
@@ -93,7 +93,7 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endDocument()
+ * @see org.apache.fop.fo.FOEventHandler#endDocument()
*/
public void endDocument() throws SAXException {
// finish all open elements
@@ -110,7 +110,7 @@ public class MIFHandler extends FOInputHandler {
* Start the page sequence.
* This creates the pages in the MIF document that will be used
* by the following flows and static areas.
- * @see org.apache.fop.fo.FOInputHandler
+ * @see org.apache.fop.fo.FOEventHandler
*/
public void startPageSequence(PageSequence pageSeq) {
// get the layout master set
@@ -157,13 +157,13 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endPageSequence(PageSequence)
+ * @see org.apache.fop.fo.FOEventHandler#endPageSequence(PageSequence)
*/
public void endPageSequence(PageSequence pageSeq) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFlow(Flow)
+ * @see org.apache.fop.fo.FOEventHandler#startFlow(Flow)
*/
public void startFlow(Flow fl) {
// start text flow in body region
@@ -171,7 +171,7 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFlow(Flow)
+ * @see org.apache.fop.fo.FOEventHandler#endFlow(Flow)
*/
public void endFlow(Flow fl) {
textFlow.finish(true);
@@ -180,7 +180,7 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startBlock(Block)
+ * @see org.apache.fop.fo.FOEventHandler#startBlock(Block)
*/
public void startBlock(Block bl) {
para = new MIFElement("Para");
@@ -189,7 +189,7 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endBlock(Block)
+ * @see org.apache.fop.fo.FOEventHandler#endBlock(Block)
*/
public void endBlock(Block bl) {
para.finish(true);
@@ -211,13 +211,13 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startTable(Table)
+ * @see org.apache.fop.fo.FOEventHandler#startTable(Table)
*/
public void startTable(Table tbl) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endTable(Table)
+ * @see org.apache.fop.fo.FOEventHandler#endTable(Table)
*/
public void endTable(Table tbl) {
}
@@ -237,201 +237,201 @@ public class MIFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startHeader(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#startHeader(TableBody)
*/
public void startHeader(TableBody th) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endHeader(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#endHeader(TableBody)
*/
public void endHeader(TableBody th) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFooter(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#startFooter(TableBody)
*/
public void startFooter(TableBody tf) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFooter(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#endFooter(TableBody)
*/
public void endFooter(TableBody tf) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startBody(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#startBody(TableBody)
*/
public void startBody(TableBody tb) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endBody(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#endBody(TableBody)
*/
public void endBody(TableBody tb) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startRow(TableRow)
+ * @see org.apache.fop.fo.FOEventHandler#startRow(TableRow)
*/
public void startRow(TableRow tr) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endRow(TableRow)
+ * @see org.apache.fop.fo.FOEventHandler#endRow(TableRow)
*/
public void endRow(TableRow tr) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startCell(TableCell)
+ * @see org.apache.fop.fo.FOEventHandler#startCell(TableCell)
*/
public void startCell(TableCell tc) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endCell(TableCell)
+ * @see org.apache.fop.fo.FOEventHandler#endCell(TableCell)
*/
public void endCell(TableCell tc) {
}
// Lists
/**
- * @see org.apache.fop.fo.FOInputHandler#startList(ListBlock)
+ * @see org.apache.fop.fo.FOEventHandler#startList(ListBlock)
*/
public void startList(ListBlock lb) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endList(ListBlock)
+ * @see org.apache.fop.fo.FOEventHandler#endList(ListBlock)
*/
public void endList(ListBlock lb) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startListItem(ListItem)
+ * @see org.apache.fop.fo.FOEventHandler#startListItem(ListItem)
*/
public void startListItem(ListItem li) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endListItem(ListItem)
+ * @see org.apache.fop.fo.FOEventHandler#endListItem(ListItem)
*/
public void endListItem(ListItem li) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startListLabel()
+ * @see org.apache.fop.fo.FOEventHandler#startListLabel()
*/
public void startListLabel() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endListLabel()
+ * @see org.apache.fop.fo.FOEventHandler#endListLabel()
*/
public void endListLabel() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startListBody()
+ * @see org.apache.fop.fo.FOEventHandler#startListBody()
*/
public void startListBody() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endListBody()
+ * @see org.apache.fop.fo.FOEventHandler#endListBody()
*/
public void endListBody() {
}
// Static Regions
/**
- * @see org.apache.fop.fo.FOInputHandler#startStatic()
+ * @see org.apache.fop.fo.FOEventHandler#startStatic()
*/
public void startStatic() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endStatic()
+ * @see org.apache.fop.fo.FOEventHandler#endStatic()
*/
public void endStatic() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startMarkup()
+ * @see org.apache.fop.fo.FOEventHandler#startMarkup()
*/
public void startMarkup() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endMarkup()
+ * @see org.apache.fop.fo.FOEventHandler#endMarkup()
*/
public void endMarkup() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startLink(BasicLink basicLink)
+ * @see org.apache.fop.fo.FOEventHandler#startLink(BasicLink basicLink)
*/
public void startLink(BasicLink basicLink) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endLink()
+ * @see org.apache.fop.fo.FOEventHandler#endLink()
*/
public void endLink() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#image(ExternalGraphic)
+ * @see org.apache.fop.fo.FOEventHandler#image(ExternalGraphic)
*/
public void image(ExternalGraphic eg) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#pageRef()
+ * @see org.apache.fop.fo.FOEventHandler#pageRef()
*/
public void pageRef() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#foreignObject(InstreamForeignObject)
+ * @see org.apache.fop.fo.FOEventHandler#foreignObject(InstreamForeignObject)
*/
public void foreignObject(InstreamForeignObject ifo) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFootnote(Footnote)
+ * @see org.apache.fop.fo.FOEventHandler#startFootnote(Footnote)
*/
public void startFootnote(Footnote footnote) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFootnote(Footnote)
+ * @see org.apache.fop.fo.FOEventHandler#endFootnote(Footnote)
*/
public void endFootnote(Footnote footnote) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFootnoteBody(FootnoteBody)
+ * @see org.apache.fop.fo.FOEventHandler#startFootnoteBody(FootnoteBody)
*/
public void startFootnoteBody(FootnoteBody body) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFootnoteBody(FootnoteBody)
+ * @see org.apache.fop.fo.FOEventHandler#endFootnoteBody(FootnoteBody)
*/
public void endFootnoteBody(FootnoteBody body) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#leader(Leader)
+ * @see org.apache.fop.fo.FOEventHandler#leader(Leader)
*/
public void leader(Leader l) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#characters(char[], int, int)
+ * @see org.apache.fop.fo.FOEventHandler#characters(char[], int, int)
*/
public void characters(char data[], int start, int length) {
if (para != null) {
diff --git a/src/java/org/apache/fop/fo/FOInputHandler.java b/src/java/org/apache/fop/fo/FOEventHandler.java
index 0cffe83c3..c24272c20 100644
--- a/src/java/org/apache/fop/fo/FOInputHandler.java
+++ b/src/java/org/apache/fop/fo/FOEventHandler.java
@@ -53,14 +53,14 @@ import org.apache.commons.logging.LogFactory;
* Abstract class defining what should be done with SAX events that map to
* XSL-FO input. The events are actually captured by fo/FOTreeBuilder, passed
* to the various fo Objects, which in turn, if needed, pass them to an instance
- * of FOInputHandler.
+ * of FOEventHandler.
*
* Sub-classes will generally fall into one of two categories:
* 1) a handler that actually builds an FO Tree from the events, or 2) a
* handler that builds a structured (as opposed to formatted) document, such
* as our MIF and RTF output targets.
*/
-public abstract class FOInputHandler {
+public abstract class FOEventHandler {
/**
* The FOUserAgent for this process
@@ -72,8 +72,8 @@ public abstract class FOInputHandler {
*/
protected FontInfo fontInfo;
- /** Logger for FOInputHandler-related messages **/
- protected static Log logger = LogFactory.getLog(FOInputHandler.class);
+ /** Logger for FOEventHandler-related messages **/
+ protected static Log logger = LogFactory.getLog(FOEventHandler.class);
/**
* The current set of id's in the FO tree.
@@ -85,7 +85,7 @@ public abstract class FOInputHandler {
* Main constructor
* @param FOUserAgent the apps.FOUserAgent instance for this process
*/
- public FOInputHandler(FOUserAgent foUserAgent) {
+ public FOEventHandler(FOUserAgent foUserAgent) {
this.foUserAgent = foUserAgent;
this.fontInfo = new FontInfo();
}
@@ -107,7 +107,7 @@ public abstract class FOInputHandler {
}
/**
* Returns the User Agent object associated with this FOInputHandler.
* @return the User Agent object
*/
public FOUserAgent getUserAgent() {
@@ -107,7 +107,7 @@ public abstract class FOInputHandler {
}
/**
- * Returns the User Agent object associated with this FOInputHandler.
+ * Returns the User Agent object associated with this FOEventHandler.
* @return the User Agent object
*/
diff --git a/src/java/org/apache/fop/fo/FONode.java b/src/java/org/apache/fop/fo/FONode.java
index c42577f7c..0b422bc8b 100644
--- a/src/java/org/apache/fop/fo/FONode.java
+++ b/src/java/org/apache/fop/fo/FONode.java
@@ -42,10 +42,10 @@ public abstract class FONode {
protected static String FO_URI = FOElementMapping.URI;
/**
* FOInputHandler that handles FO events occurring
* during FO Tree processing.
*/
- protected static FOInputHandler foInputHandler = null;
+ protected static FOEventHandler foEventHandler = null;
/** Parent FO node */
protected FONode parent;
@@ -79,20 +79,20 @@ public abstract class FONode {
}
/**
* Sets the FOInputHandler that the FOTree processing fires events to
* @param inputHandler the FOInputHandler subclass to send FO events to
*/
- public static void setFOInputHandler(FOInputHandler inputHandler) {
- FONode.foInputHandler = inputHandler;
+ public static void setFOEventHandler(FOEventHandler eventHandler) {
+ FONode.foEventHandler = eventHandler;
}
/**
* Recursively goes up the FOTree hierarchy until the fo:root is found,
* which returns the parent FOInputHandler.
* @return the FOInputHandler object that is the parent of the FO Tree
*/
- public FOInputHandler getFOInputHandler() {
- return FONode.foInputHandler;
+ public FOEventHandler getFOEventHandler() {
+ return FONode.foEventHandler;
}
/**
@@ -100,7 +100,7 @@ public abstract class FONode {
* @return FOUserAgent
*/
public FOUserAgent getUserAgent() {
- return getFOInputHandler().getUserAgent();
+ return getFOEventHandler().getUserAgent();
}
/**
@@ -42,10 +42,10 @@ public abstract class FONode {
protected static String FO_URI = FOElementMapping.URI;
/**
- * FOInputHandler that handles FO events occurring
+ * FOEventHandler that handles FO events occurring
* during FO Tree processing.
*/
@@ -79,20 +79,20 @@ public abstract class FONode {
}
/**
- * Sets the FOInputHandler that the FOTree processing fires events to
- * @param inputHandler the FOInputHandler subclass to send FO events to
+ * Sets the FOEventHandler that the FOTree processing fires events to
+ * @param eventHandler the FOEventHandler subclass to send FO events to
*/
@@ -79,20 +79,20 @@ public abstract class FONode {
/**
* Recursively goes up the FOTree hierarchy until the fo:root is found,
- * which returns the parent FOInputHandler.
- * @return the FOInputHandler object that is the parent of the FO Tree
+ * which returns the parent FOEventHandler.
+ * @return the FOEventHandler object that is the parent of the FO Tree
*/
diff --git a/src/java/org/apache/fop/fo/flow/Footnote.java b/src/java/org/apache/fop/fo/flow/Footnote.java
index 8dc407708..27159da73 100644
--- a/src/java/org/apache/fop/fo/flow/Footnote.java
+++ b/src/java/org/apache/fop/fo/flow/Footnote.java
@@ -50,7 +50,7 @@ public class Footnote extends FObj {
*/
protected void addProperties(Attributes attlist) throws SAXParseException {
super.addProperties(attlist);
- getFOInputHandler().startFootnote(this);
+ getFOEventHandler().startFootnote(this);
}
/**
@@ -81,7 +81,7 @@ public class Footnote extends FObj {
/**
* Make sure content model satisfied, if so then tell the
* FOInputHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
@@ -89,7 +89,7 @@ public class Footnote extends FObj {
if (inlineFO == null || footnoteBody == null) {
missingChildElementError("(inline,footnote-body)");
}
- getFOInputHandler().endFootnote(this);
+ getFOEventHandler().endFootnote(this);
}
/**
@@ -81,7 +81,7 @@ public class Footnote extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
diff --git a/src/java/org/apache/fop/fo/flow/FootnoteBody.java b/src/java/org/apache/fop/fo/flow/FootnoteBody.java
index d8734f4d4..69c25ba84 100644
--- a/src/java/org/apache/fop/fo/flow/FootnoteBody.java
+++ b/src/java/org/apache/fop/fo/flow/FootnoteBody.java
@@ -44,7 +44,7 @@ public class FootnoteBody extends FObj {
*/
protected void addProperties(Attributes attlist) throws SAXParseException {
super.addProperties(attlist);
- getFOInputHandler().startFootnoteBody(this);
+ getFOEventHandler().startFootnoteBody(this);
}
/**
@@ -60,14 +60,14 @@ public class FootnoteBody extends FObj {
/**
* Make sure content model satisfied, if so then tell the
* FOInputHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
if (childNodes == null) {
missingChildElementError("(%block;)+");
}
- getFOInputHandler().endFootnoteBody(this);
+ getFOEventHandler().endFootnoteBody(this);
}
/**
@@ -60,14 +60,14 @@ public class FootnoteBody extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
diff --git a/src/java/org/apache/fop/fo/flow/ListBlock.java b/src/java/org/apache/fop/fo/flow/ListBlock.java
index 58e0a024b..6261950f3 100644
--- a/src/java/org/apache/fop/fo/flow/ListBlock.java
+++ b/src/java/org/apache/fop/fo/flow/ListBlock.java
@@ -52,7 +52,7 @@ public class ListBlock extends FObj {
*/
protected void addProperties(Attributes attlist) throws SAXParseException {
super.addProperties(attlist);
- getFOInputHandler().startList(this);
+ getFOEventHandler().startList(this);
}
/**
@@ -74,14 +74,14 @@ public class ListBlock extends FObj {
/**
* Make sure content model satisfied, if so then tell the
* FOInputHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
if (!hasListItem) {
missingChildElementError("marker* (list-item)+");
}
- getFOInputHandler().endList(this);
+ getFOEventHandler().endList(this);
}
/**
@@ -74,14 +74,14 @@ public class ListBlock extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
diff --git a/src/java/org/apache/fop/fo/flow/ListItem.java b/src/java/org/apache/fop/fo/flow/ListItem.java
index 7fd8170b2..7b66f5dde 100644
--- a/src/java/org/apache/fop/fo/flow/ListItem.java
+++ b/src/java/org/apache/fop/fo/flow/ListItem.java
@@ -51,7 +51,7 @@ public class ListItem extends FObj {
*/
protected void addProperties(Attributes attlist) throws SAXParseException {
super.addProperties(attlist);
- getFOInputHandler().startListItem(this);
+ getFOEventHandler().startListItem(this);
}
/**
@@ -98,14 +98,14 @@ public class ListItem extends FObj {
/**
* Make sure content model satisfied, if so then tell the
* FOInputHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
if (label == null || body == null) {
missingChildElementError("marker* (list-item-label,list-item-body)");
}
- getFOInputHandler().endListItem(this);
+ getFOEventHandler().endListItem(this);
}
/**
@@ -98,14 +98,14 @@ public class ListItem extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
diff --git a/src/java/org/apache/fop/fo/flow/TableCell.java b/src/java/org/apache/fop/fo/flow/TableCell.java
index 944e943c5..212186b6f 100644
--- a/src/java/org/apache/fop/fo/flow/TableCell.java
+++ b/src/java/org/apache/fop/fo/flow/TableCell.java
@@ -158,7 +158,7 @@ public class TableCell extends FObj {
}
this.minCellHeight = getPropLength(PR_HEIGHT);
- getFOInputHandler().startCell(this);
+ getFOEventHandler().startCell(this);
}
/**
@@ -180,14 +180,14 @@ public class TableCell extends FObj {
/**
* Make sure content model satisfied, if so then tell the
* FOInputHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
if (!blockItemFound) {
missingChildElementError("marker* (%block;)+");
}
- getFOInputHandler().endCell(this);
+ getFOEventHandler().endCell(this);
}
/**
@@ -180,14 +180,14 @@ public class TableCell extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
diff --git a/src/java/org/apache/fop/fo/pagination/Flow.java b/src/java/org/apache/fop/fo/pagination/Flow.java
index fb1b50802..2a7589830 100644
--- a/src/java/org/apache/fop/fo/pagination/Flow.java
+++ b/src/java/org/apache/fop/fo/pagination/Flow.java
@@ -71,7 +71,7 @@ public class Flow extends FObj {
missingPropertyError("flow-name");
}
- getFOInputHandler().startFlow(this);
+ getFOEventHandler().startFlow(this);
}
/**
@@ -93,14 +93,14 @@ public class Flow extends FObj {
/**
* Make sure content model satisfied, if so then tell the
* FOInputHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
if (!blockItemFound) {
missingChildElementError("marker* (%block;)+");
}
- getFOInputHandler().endFlow(this);
+ getFOEventHandler().endFlow(this);
}
/**
@@ -93,14 +93,14 @@ public class Flow extends FObj {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
diff --git a/src/java/org/apache/fop/fo/pagination/StaticContent.java b/src/java/org/apache/fop/fo/pagination/StaticContent.java
index 6e9441afb..0cb8abc0a 100644
--- a/src/java/org/apache/fop/fo/pagination/StaticContent.java
+++ b/src/java/org/apache/fop/fo/pagination/StaticContent.java
@@ -51,14 +51,14 @@ public class StaticContent extends Flow {
/**
* Make sure content model satisfied, if so then tell the
* FOInputHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
protected void endOfNode() throws SAXParseException {
if (childNodes == null) {
missingChildElementError("(%block;)+");
}
- getFOInputHandler().endFlow(this);
+ getFOEventHandler().endFlow(this);
}
/**
@@ -51,14 +51,14 @@ public class StaticContent extends Flow {
/**
* Make sure content model satisfied, if so then tell the
- * FOInputHandler that we are at the end of the flow.
+ * FOEventHandler that we are at the end of the flow.
* @see org.apache.fop.fo.FONode#end
*/
diff --git a/src/java/org/apache/fop/render/rtf/RTFHandler.java b/src/java/org/apache/fop/render/rtf/RTFHandler.java
index 8ac6f46b9..60162c3d0 100644
--- a/src/java/org/apache/fop/render/rtf/RTFHandler.java
+++ b/src/java/org/apache/fop/render/rtf/RTFHandler.java
@@ -28,7 +28,7 @@ import org.apache.commons.logging.impl.SimpleLog;
import org.apache.commons.logging.Log;
import org.apache.fop.apps.FOPException;
import org.apache.fop.apps.FOUserAgent;
-import org.apache.fop.fo.FOInputHandler;
+import org.apache.fop.fo.FOEventHandler;
import org.apache.fop.fo.FObj;
import org.apache.fop.fo.flow.BasicLink;
import org.apache.fop.fo.flow.Block;
@@ -94,7 +94,7 @@ import org.xml.sax.SAXException;
* @author Peter Herweg <pherweg@web.de>
* @author Andreas Putz <a.putz@skynamics.com>
*/
-public class RTFHandler extends FOInputHandler {
+public class RTFHandler extends FOEventHandler {
private RtfFile rtfFile;
private final OutputStream os;
@@ -136,7 +136,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startDocument()
+ * @see org.apache.fop.fo.FOEventHandler#startDocument()
*/
public void startDocument() throws SAXException {
// TODO sections should be created
@@ -144,25 +144,25 @@ public class RTFHandler extends FOInputHandler {
rtfFile = new RtfFile(new OutputStreamWriter(os));
docArea = rtfFile.startDocumentArea();
} catch (IOException ioe) {
// TODO could we throw Exception in all FOInputHandler events?
throw new SAXException(ioe);
}
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endDocument()
+ * @see org.apache.fop.fo.FOEventHandler#endDocument()
*/
public void endDocument() throws SAXException {
try {
rtfFile.flush();
} catch (IOException ioe) {
// TODO could we throw Exception in all FOInputHandler events?
throw new SAXException(ioe);
}
}
/**
- * @see org.apache.fop.fo.FOInputHandler
+ * @see org.apache.fop.fo.FOEventHandler
*/
public void startPageSequence(PageSequence pageSeq) {
try {
@@ -193,14 +193,14 @@ public class RTFHandler extends FOInputHandler {
bHeaderSpecified = false;
bFooterSpecified = false;
} catch (IOException ioe) {
// TODO could we throw Exception in all FOInputHandler events?
log.error("startPageSequence: " + ioe.getMessage());
//TODO throw new FOPException(ioe);
}
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endPageSequence(PageSequence)
+ * @see org.apache.fop.fo.FOEventHandler#endPageSequence(PageSequence)
*/
public void endPageSequence(PageSequence pageSeq) {
if (bDefer) {
@@ -211,7 +211,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFlow(Flow)
+ * @see org.apache.fop.fo.FOEventHandler#startFlow(Flow)
*/
public void startFlow(Flow fl) {
if (bDefer) {
@@ -290,7 +290,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFlow(Flow)
+ * @see org.apache.fop.fo.FOEventHandler#endFlow(Flow)
*/
public void endFlow(Flow fl) {
if (bDefer) {
@@ -312,7 +312,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startBlock(Block)
+ * @see org.apache.fop.fo.FOEventHandler#startBlock(Block)
*/
public void startBlock(Block bl) {
++iNestCount;
@@ -342,7 +342,7 @@ public class RTFHandler extends FOInputHandler {
textrun.addParagraphBreak();
textrun.pushAttributes(rtfAttr);
} catch (IOException ioe) {
// TODO could we throw Exception in all FOInputHandler events?
log.error("startBlock: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
} catch (Exception e) {
@@ -353,7 +353,7 @@ public class RTFHandler extends FOInputHandler {
/**
- * @see org.apache.fop.fo.FOInputHandler#endBlock(Block)
+ * @see org.apache.fop.fo.FOEventHandler#endBlock(Block)
*/
public void endBlock(Block bl) {
--iNestCount;
@@ -398,7 +398,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startTable(Table)
+ * @see org.apache.fop.fo.FOEventHandler#startTable(Table)
*/
public void startTable(Table tbl) {
if (bDefer) {
@@ -425,7 +425,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endTable(Table)
+ * @see org.apache.fop.fo.FOEventHandler#endTable(Table)
*/
public void endTable(Table tbl) {
if (bDefer) {
@@ -469,25 +469,25 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startHeader(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#startHeader(TableBody)
*/
public void startHeader(TableBody th) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endHeader(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#endHeader(TableBody)
*/
public void endHeader(TableBody th) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFooter(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#startFooter(TableBody)
*/
public void startFooter(TableBody tf) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFooter(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#endFooter(TableBody)
*/
public void endFooter(TableBody tf) {
}
@@ -549,7 +549,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startBody(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#startBody(TableBody)
*/
public void startBody(TableBody tb) {
if (bDefer) {
@@ -569,7 +569,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endBody(TableBody)
+ * @see org.apache.fop.fo.FOEventHandler#endBody(TableBody)
*/
public void endBody(TableBody tb) {
if (bDefer) {
@@ -586,7 +586,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startRow(TableRow)
+ * @see org.apache.fop.fo.FOEventHandler#startRow(TableRow)
*/
public void startRow(TableRow tr) {
if (bDefer) {
@@ -616,7 +616,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endRow(TableRow)
+ * @see org.apache.fop.fo.FOEventHandler#endRow(TableRow)
*/
public void endRow(TableRow tr) {
if (bDefer) {
@@ -628,7 +628,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startCell(TableCell)
+ * @see org.apache.fop.fo.FOEventHandler#startCell(TableCell)
*/
public void startCell(TableCell tc) {
if (bDefer) {
@@ -678,7 +678,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endCell(TableCell)
+ * @see org.apache.fop.fo.FOEventHandler#endCell(TableCell)
*/
public void endCell(TableCell tc) {
if (bDefer) {
@@ -691,7 +691,7 @@ public class RTFHandler extends FOInputHandler {
// Lists
/**
- * @see org.apache.fop.fo.FOInputHandler#startList(ListBlock)
+ * @see org.apache.fop.fo.FOEventHandler#startList(ListBlock)
*/
public void startList(ListBlock lb) {
if (bDefer) {
@@ -719,7 +719,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endList(ListBlock)
+ * @see org.apache.fop.fo.FOEventHandler#endList(ListBlock)
*/
public void endList(ListBlock lb) {
if (bDefer) {
@@ -730,7 +730,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startListItem(ListItem)
+ * @see org.apache.fop.fo.FOEventHandler#startListItem(ListItem)
*/
public void startListItem(ListItem li) {
if (bDefer) {
@@ -755,7 +755,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endListItem(ListItem)
+ * @see org.apache.fop.fo.FOEventHandler#endListItem(ListItem)
*/
public void endListItem(ListItem li) {
if (bDefer) {
@@ -766,7 +766,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startListLabel()
+ * @see org.apache.fop.fo.FOEventHandler#startListLabel()
*/
public void startListLabel() {
if (bDefer) {
@@ -789,7 +789,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endListLabel()
+ * @see org.apache.fop.fo.FOEventHandler#endListLabel()
*/
public void endListLabel() {
if (bDefer) {
@@ -800,44 +800,44 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startListBody()
+ * @see org.apache.fop.fo.FOEventHandler#startListBody()
*/
public void startListBody() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endListBody()
+ * @see org.apache.fop.fo.FOEventHandler#endListBody()
*/
public void endListBody() {
}
// Static Regions
/**
- * @see org.apache.fop.fo.FOInputHandler#startStatic()
+ * @see org.apache.fop.fo.FOEventHandler#startStatic()
*/
public void startStatic() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endStatic()
+ * @see org.apache.fop.fo.FOEventHandler#endStatic()
*/
public void endStatic() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startMarkup()
+ * @see org.apache.fop.fo.FOEventHandler#startMarkup()
*/
public void startMarkup() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endMarkup()
+ * @see org.apache.fop.fo.FOEventHandler#endMarkup()
*/
public void endMarkup() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startLink(BasicLink basicLink)
+ * @see org.apache.fop.fo.FOEventHandler#startLink(BasicLink basicLink)
*/
public void startLink(BasicLink basicLink) {
if (bDefer) {
@@ -876,7 +876,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endLink()
+ * @see org.apache.fop.fo.FOEventHandler#endLink()
*/
public void endLink() {
if (bDefer) {
@@ -887,7 +887,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#image(ExternalGraphic)
+ * @see org.apache.fop.fo.FOEventHandler#image(ExternalGraphic)
*/
public void image(ExternalGraphic eg) {
if (bDefer) {
@@ -956,19 +956,19 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#pageRef()
+ * @see org.apache.fop.fo.FOEventHandler#pageRef()
*/
public void pageRef() {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#foreignObject(InstreamForeignObject)
+ * @see org.apache.fop.fo.FOEventHandler#foreignObject(InstreamForeignObject)
*/
public void foreignObject(InstreamForeignObject ifo) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFootnote(Footnote)
+ * @see org.apache.fop.fo.FOEventHandler#startFootnote(Footnote)
*/
public void startFootnote(Footnote footnote) {
if (bDefer) {
@@ -990,7 +990,7 @@ public class RTFHandler extends FOInputHandler {
builderContext.pushContainer(rtfFootnote);
} catch (IOException ioe) {
// TODO could we throw Exception in all FOInputHandler events?
log.error("startFootnote: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
} catch (Exception e) {
@@ -1000,7 +1000,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFootnote(Footnote)
+ * @see org.apache.fop.fo.FOEventHandler#endFootnote(Footnote)
*/
public void endFootnote(Footnote footnote) {
if (bDefer) {
@@ -1011,7 +1011,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#startFootnoteBody(FootnoteBody)
+ * @see org.apache.fop.fo.FOEventHandler#startFootnoteBody(FootnoteBody)
*/
public void startFootnoteBody(FootnoteBody body) {
if (bDefer) {
@@ -1026,7 +1026,7 @@ public class RTFHandler extends FOInputHandler {
rtfFootnote.startBody();
} catch (IOException ioe) {
// TODO could we throw Exception in all FOInputHandler events?
log.error("startFootnoteBody: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
} catch (Exception e) {
@@ -1036,7 +1036,7 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#endFootnoteBody(FootnoteBody)
+ * @see org.apache.fop.fo.FOEventHandler#endFootnoteBody(FootnoteBody)
*/
public void endFootnoteBody(FootnoteBody body) {
if (bDefer) {
@@ -1051,7 +1051,7 @@ public class RTFHandler extends FOInputHandler {
rtfFootnote.endBody();
} catch (IOException ioe) {
// TODO could we throw Exception in all FOInputHandler events?
log.error("endFootnoteBody: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
} catch (Exception e) {
@@ -1061,13 +1061,13 @@ public class RTFHandler extends FOInputHandler {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#leader(Leader)
+ * @see org.apache.fop.fo.FOEventHandler#leader(Leader)
*/
public void leader(Leader l) {
}
/**
- * @see org.apache.fop.fo.FOInputHandler#characters(char[], int, int)
+ * @see org.apache.fop.fo.FOEventHandler#characters(char[], int, int)
*/
public void characters(char[] data, int start, int length) {
if (bDefer) {
@@ -1082,7 +1082,7 @@ public class RTFHandler extends FOInputHandler {
RtfTextrun textrun = container.getTextrun();
textrun.addString(new String(data, start, length-start));
} catch (IOException ioe) {
// FIXME could we throw Exception in all FOInputHandler events?
log.error("characters: " + ioe.getMessage());
throw new RuntimeException(ioe.getMessage());
} catch (Exception e) {
@@ -144,25 +144,25 @@ public class RTFHandler extends FOInputHandler {
docArea = rtfFile.startDocumentArea();
} catch (IOException ioe) {
- // TODO could we throw Exception in all FOInputHandler events?
+ // TODO could we throw Exception in all FOEventHandler events?
throw new SAXException(ioe);
}
@@ -144,25 +144,25 @@ public class RTFHandler extends FOInputHandler {
rtfFile.flush();
} catch (IOException ioe) {
- // TODO could we throw Exception in all FOInputHandler events?
+ // TODO could we throw Exception in all FOEventHandler events?
throw new SAXException(ioe);
}
@@ -193,14 +193,14 @@ public class RTFHandler extends FOInputHandler {
bFooterSpecified = false;
} catch (IOException ioe) {
- // TODO could we throw Exception in all FOInputHandler events?
+ // TODO could we throw Exception in all FOEventHandler events?
log.error("startPageSequence: " + ioe.getMessage());
//TODO throw new FOPException(ioe);
@@ -342,7 +342,7 @@ public class RTFHandler extends FOInputHandler {
textrun.pushAttributes(rtfAttr);
} catch (IOException ioe) {
- // TODO could we throw Exception in all FOInputHandler events?
+ // TODO could we throw Exception in all FOEventHandler events?
log.error("startBlock: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
@@ -990,7 +990,7 @@ public class RTFHandler extends FOInputHandler {
builderContext.pushContainer(rtfFootnote);
} catch (IOException ioe) {
- // TODO could we throw Exception in all FOInputHandler events?
+ // TODO could we throw Exception in all FOEventHandler events?
log.error("startFootnote: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
@@ -1026,7 +1026,7 @@ public class RTFHandler extends FOInputHandler {
rtfFootnote.startBody();
} catch (IOException ioe) {
- // TODO could we throw Exception in all FOInputHandler events?
+ // TODO could we throw Exception in all FOEventHandler events?
log.error("startFootnoteBody: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
@@ -1051,7 +1051,7 @@ public class RTFHandler extends FOInputHandler {
rtfFootnote.endBody();
} catch (IOException ioe) {
- // TODO could we throw Exception in all FOInputHandler events?
+ // TODO could we throw Exception in all FOEventHandler events?
log.error("endFootnoteBody: " + ioe.getMessage());
throw new RuntimeException("IOException: " + ioe);
@@ -1082,7 +1082,7 @@ public class RTFHandler extends FOInputHandler {
textrun.addString(new String(data, start, length-start));
} catch (IOException ioe) {
- // FIXME could we throw Exception in all FOInputHandler events?
+ // FIXME could we throw Exception in all FOEventHandler events?
log.error("characters: " + ioe.getMessage());
throw new RuntimeException(ioe.getMessage());